/***************************************************************
 * Name:      wx016Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2025-01-04
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx016Main.h"
#include "fecha.xpm"
#include "nombre.xpm"
#include "titulo.xpm"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx016Frame, wxFrame)
    EVT_CLOSE(wx016Frame::OnClose)
    EVT_MENU(idMenuQuit, wx016Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx016Frame::OnAbout)
END_EVENT_TABLE()

wx016Frame::wx016Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title, wxDefaultPosition, wxSize(400,200))
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Abandonar la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);


    wxBoxSizer *boxVertical;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    headerCtrl = new MiHeaderCtrl(this, idHeader, wxDefaultPosition, wxDefaultSize, wxHD_BITMAP_ON_RIGHT | wxHD_DEFAULT_STYLE | wxHD_ALLOW_HIDE);
    InsertaColumna(_T("Autor"), 100, nombre_xpm);
    InsertaColumna(_T("Título"), 100, titulo_xpm);
    InsertaColumna(_T("Fecha"), 80, fecha_xpm);

    headerCtrl->HideColumn(1);
    headerCtrl->ShowSortIndicator(0, true);
    //headerCtrl->RemoveSortIndicator();

    boxVertical->Add(headerCtrl, wxSizerFlags().Expand().Border());

    SetSizer(boxVertical);
}

void wx016Frame::InsertaColumna(const wxString& etq, int ancho, const wxBitmapBundle& bm) {
    wxHeaderColumnSimple col(etq, FromDIP(ancho), wxALIGN_LEFT, wxCOL_RESIZABLE | wxCOL_REORDERABLE | wxCOL_SORTABLE);
    col.SetBitmap(bm);
    headerCtrl->AppendColumn(col);
}

wx016Frame::~wx016Frame()
{
}

void wx016Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx016Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx016Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Bienvenido a..."));
}

